import React from 'react';
import Modal from 'react-modal';
import { useSelector, useDispatch } from 'react-redux';
import PropTypes from 'prop-types';
import { VEHICLE_CERTIFICATION, COMPONENTS } from 'common/ui-labels';
import { selectDeleteDriverStatus, selectCheckedDrivers, selectCheckedVMs } from '../store/selectors';
import { closeDeleteDriverCertificationModal, deleteDriverCertification, unselectTableDrivers } from '../store/actions';


function DeleteDriverCertificationsForm(props) {
    // todo: implement submitted and use DeleteButtons common component
    const { close, submit, className } = props;
    return (
        <form className={className}>
            <div
                className="col-md-12"
                style={{ overflowY: 'auto', overflowX: 'hidden' }}
            >
                <div className="Form-Buttons">
                    <button type="button" onClick={submit} data-id="driver-delete-ok">{COMPONENTS.BUTTONS.OK}</button>
                    <button type="button" data-id="driver-delete-cancel" onClick={close}>{COMPONENTS.BUTTONS.CANCEL}</button>
                </div>
            </div>
        </form>
    );
}

DeleteDriverCertificationsForm.defaultProps = {
    close: () => {},
    submit: () => {},
    className: '',
};

DeleteDriverCertificationsForm.propTypes = {
    close: PropTypes.func,
    submit: PropTypes.func,
    className: PropTypes.string,
};

export default function DeleteDriverCertifications(props) {
    const dispatch = useDispatch();
    const open = useSelector(selectDeleteDriverStatus);
    const vehicleModels = useSelector(selectCheckedVMs);
    const drivers = useSelector(selectCheckedDrivers);
    const { style } = props;
    
    function submit() {
        dispatch(deleteDriverCertification(drivers, vehicleModels[0]));
        dispatch(unselectTableDrivers(drivers));
        dispatch(closeDeleteDriverCertificationModal());
    }
    function close() {
        dispatch(closeDeleteDriverCertificationModal());
    }
    
    return (
        <Modal
            contentLabel="deleteDriverCertification"
            isOpen={open}
            style={style}
        >
            <div className="RPP-Modal">
                <span className="Modal-Header">
                    {VEHICLE_CERTIFICATION.DELETE_CERTIFICATION_MODAL_TITLE}
                </span>
                <DeleteDriverCertificationsForm
                    className="Modal-Form"
                    close={close}
                    submit={submit}
                />
            </div>
        </Modal>
    );
}

DeleteDriverCertifications.propTypes = {
    style: PropTypes.shape({}),
};

DeleteDriverCertifications.defaultProps = {
    style: {},
};
