import React from 'react';
import { Field, reduxForm } from 'redux-form';
import { connect } from 'react-redux';
import _IsEmpty from 'lodash/isEmpty';
import { injectIntl } from 'react-intl';
import PropTypes from 'prop-types';
import { COMPONENTS, VEHICLE_CERTIFICATION } from 'common/ui-labels';
import { FORMS_NAME } from '../../common/constants';
import { selectCheckedVMs, selectDrivers } from '../../store/selectors';
import MultiSelectComponent from '../../../../src/js/components/modals/MultiSelectComponent';
import SaveButtons from '../../../../src/js/components/modals/SaveButtons';
import { filterSelectBoxOptions } from '../../../../src/js/utils/utils';


const required = value => (_IsEmpty(value) ? 'Required' : undefined);

let EditDriverCertificationForm = (props) => {
    const { close, className, drivers, submit, invalid, intl } = props;

    return (
        <form className={className} onSubmit={(e) => { e.preventDefault(); }}>
            <div className="Form-Line row">
                <div className="Form-Label col-md-4">{VEHICLE_CERTIFICATION.DRIVERS}*</div>
                <div className="col-md-8">
                    <Field
                        name="drivers"
                        dataId="driver-certification-edit"
                        component={MultiSelectComponent}
                        placeholder={COMPONENTS.SELECT_COMPONENT_PLACEHOLDER(intl)}
                        noResultsText={COMPONENTS.SELECT_COMPONENT_NO_RESULTS_TEXT}
                        options={drivers}
                        filterOptions={filterSelectBoxOptions}
                        validate={[required]}
                    />
                </div>
            </div>
            <SaveButtons
                submit={submit}
                close={close}
                disabled={invalid}
                dataId="driver-certification-edit"
            />
        </form>
    );
};

EditDriverCertificationForm.propTypes = {
    close: PropTypes.func,
    submit: PropTypes.func,
    intl: PropTypes.shape({ formatMessage: PropTypes.func }),
    className: PropTypes.string,
    drivers: PropTypes.arrayOf(PropTypes.shape()),
    invalid: PropTypes.bool,
};

EditDriverCertificationForm.defaultProps = {
    close: () => {},
    submit: () => {},
    intl: {
        formatMessage: () => {
        },
    },
    className: '',
    drivers: [],
    invalid: false,
};

EditDriverCertificationForm = reduxForm({
    form: FORMS_NAME.DRIVER_LICENSES_EDIT_FORM,
})(EditDriverCertificationForm);

const mapStateToForm = (state) => {
    const drivers = selectDrivers(state);
    const checkedVehicleModels = selectCheckedVMs(state) || {};
    
    return ({
        drivers: drivers.reduce((memo, driver) => {
            if (!driver.vehicleModelsIds.includes(checkedVehicleModels[0].id)) memo.push({ ...driver, value: driver.obj_uid, label: driver.name });
            return memo;
        }, []),
    });
};

EditDriverCertificationForm = connect(mapStateToForm)(injectIntl(EditDriverCertificationForm));

export default EditDriverCertificationForm;
