import React from 'react';
import Modal from 'react-modal';
import { useSelector, useDispatch } from 'react-redux';
import PropTypes from 'prop-types';
import { VEHICLE_CERTIFICATION } from 'common/ui-labels';
import { selectCheckedVMs, selectEditDriverStatus } from '../../store/selectors';
import { closeEditDriverCertificationModal, updateDriverCertification } from '../../store/actions';
import EditDriverCertificationForm from './EditDriverCertificationForm';


export default function EditDriverCertification(props) {
    const dispatch = useDispatch();
    const vehicleModels = useSelector(selectCheckedVMs);
    const open = useSelector(selectEditDriverStatus);
    const { style } = props;
    
    function submit({ drivers }) {
        const updatedData = drivers.map((driver) => {
            const certification = (driver.certification || []);
            certification.push({
                id: vehicleModels[0].id,
                name: vehicleModels[0].name,
                certification_required: vehicleModels[0].certification_required,
            });
            return { obj_uid: driver.obj_uid, certification };
        });
        dispatch(updateDriverCertification(updatedData));
        dispatch(closeEditDriverCertificationModal());
    }
    function close() {
        dispatch(closeEditDriverCertificationModal());
    }
    
    return (
        <Modal
            contentLabel="editDriverCertification"
            isOpen={open}
            style={style}
        >
            <div className="RPP-Modal">
                <div className="Modal-Header capitalizedText">
                    {VEHICLE_CERTIFICATION.EDIT_CERTIFICATION_MODAL_TITLE}
                </div>
                <div className="Modal-Header-Subtitle">
                    {VEHICLE_CERTIFICATION.EDIT_CERTIFICATION_MODAL_MESSAGE}
                </div>
                <EditDriverCertificationForm
                    className="Modal-Form"
                    close={close}
                    onSubmit={submit}
                />
            </div>
        </Modal>
    );
}

EditDriverCertification.propTypes = {
    style: PropTypes.shape({}),
};

EditDriverCertification.defaultProps = {
    style: {},
};
