import React from 'react';
import Modal from 'react-modal';
import { useSelector, useDispatch } from 'react-redux';
import PropTypes from 'prop-types';
import { VEHICLE_CERTIFICATION } from 'common/ui-labels';
import { selectVehicleModels, selectEditVMStatus, selectEditedVehModel } from '../../store/selectors';
import { closeEditCertModal, editVehicleModel, addVehicleModel } from '../../store/actions';
import EditVehicleModelForm from './EditVehicleModelForm';


export default function EditVehicleModel(props) {
    const dispatch = useDispatch();
    const open = useSelector(selectEditVMStatus);
    const vehicleModel = useSelector(selectEditedVehModel);
    const vehicleModels = useSelector(selectVehicleModels);
    const { style } = props;
    function submit(data) {
        if (vehicleModel) {
            dispatch(editVehicleModel(data));
        } else {
            dispatch(addVehicleModel(data));
        }
        dispatch(closeEditCertModal());
    }
    
    function close() {
        dispatch(closeEditCertModal());
    }
    
    return (
        <Modal
            contentLabel="editVehicleModel"
            isOpen={open}
            style={style}
        >
            <div className="RPP-Modal">
                <span className="Modal-Header">
                    {vehicleModel ? `${vehicleModel.name}` : VEHICLE_CERTIFICATION.EDIT_CERT_CLASS_MODAL_TITLE}
                </span>
                <EditVehicleModelForm
                    allModels={vehicleModels}
                    vehicleModel={vehicleModel}
                    isEditMode={!!vehicleModel}
                    className="Modal-Form"
                    close={close}
                    onSubmit={submit}
                />
            </div>
        </Modal>
    );
}

EditVehicleModel.propTypes = {
    style: PropTypes.shape({}),
};

EditVehicleModel.defaultProps = {
    style: {},
};
