import * as api from '../../api';
import { ACTIONS } from '../../common/constants';
import { errorHandlerGetRequest } from '../../../../src/js/stores/actions/errorHandlerActions';


export const loadVehicleModels = () => async (dispatch) => {
    try {
        const vehicle_models = await api.loadVehicleModels();
        dispatch({
            type: ACTIONS.VEHICLE_MODELS_SET,
            params: vehicle_models,
        });
    } catch (err) {
        errorHandlerGetRequest(err, dispatch);
    }
};

export const editVehicleModel = params => async (dispatch) => {
    try {
        const vehicle_model = await api.updateVehicleModel(params.id, params);
        dispatch({
            type: ACTIONS.VEHICLE_MODELS_UPDATED,
            params: vehicle_model,
        });
    } catch (err) {
        errorHandlerGetRequest(err, dispatch);
    }
};

export const addVehicleModel = params => async (dispatch) => {
    try {
        const vehicle_model = await api.createVehicleModel(params);
        dispatch({
            type: ACTIONS.VEHICLE_MODELS_CREATED,
            params: vehicle_model,
        });
    } catch (err) {
        errorHandlerGetRequest(err, dispatch);
    }
};

export const removeVehicleModel = params => async (dispatch) => {
    const promises = [];
    
    for (let i = 0; i < params.length; i += 1) {
        promises.push(api.deleteVehicleModel(params[i])
            .then(() => {
                dispatch({
                    type: ACTIONS.VEHICLE_MODELS_DELETED,
                    params: params[i],
                });
            })
            .catch((err) => {
                errorHandlerGetRequest(err, dispatch);
            }));
    }
    return Promise.all(promises);
};

export const selectTableVehicleModels = params => ({
    type: ACTIONS.VEHICLE_MODELS_SELECT,
    params,
});

export const selectTableVehicleModel = params => ({
    type: ACTIONS.VEHICLE_MODELS_SINGLE_SELECT,
    params,
});

export const unselectTableVehicleModels = params => ({
    type: ACTIONS.VEHICLE_MODELS_UNSELECT,
    params,
});
