import { getNotifyParams } from 'utils/storeUtils';
import { ACTIONS, NOTIFY_ACTIONS } from '../../common/constants';
import { updatedReducerFunc, singleSelectReducerFunc, bulkSelectReducerFunc, unselectReducerFunc } from '../../common/utils';


const initialState = { items: [], selected: [] };

// { obj_uid: 'xEWwRBUdTS26J2Up68dpFA', id: 1, name: 'Model A' },
const vehicleCertification = (state = initialState, action) => {
    switch (action.type) {
        case ACTIONS.VEHICLE_CERTIFICATIONS_SET: {
            return { ...initialState, items: [...action.params] };
        }
        case ACTIONS.VEHICLE_CERTIFICATIONS_CLEAR:
            return initialState;
        case ACTIONS.VEHICLE_MODELS_UPDATED: {
            const vehicleModel = action.params;
            const newState = { ...state, items: [] };
            state.items.forEach((vehicleCert) => {
                newState.items.push({
                    ...vehicleCert,
                    name: vehicleCert.id === vehicleModel.id ? vehicleModel.name : vehicleCert.name,
                    certification_required: vehicleCert.id === vehicleModel.id ? vehicleModel.certification_required : vehicleCert.certification_required,
                });
            });
            return newState;
        }
        case NOTIFY_ACTIONS.VEHICLE_CERTIFICATIONS_UPDATED:
        case ACTIONS.VEHICLE_CERTIFICATIONS_UPDATED: {
            const params = getNotifyParams(action);
            return updatedReducerFunc(state, params);
        }
        case ACTIONS.VEHICLE_CERTIFICATIONS_SINGLE_SELECT: {
            return singleSelectReducerFunc(state, action.params, 'obj_uid');
        }
        case ACTIONS.VEHICLE_CERTIFICATIONS_SELECT: {
            return bulkSelectReducerFunc(state, action.params, 'obj_uid');
        }
        case ACTIONS.VEHICLE_CERTIFICATIONS_UNSELECT: {
            return unselectReducerFunc(state, action.params, 'obj_uid');
        }
        case ACTIONS.CLEAR_SELECTED_DRIVERS_VEHICLES: {
            return { ...state, selected: [] };
        }
        default:
            return state;
    }
};

export default vehicleCertification;
