const { db } = require('../../../../routes/global');
const {
    deleteVehiclesModelAssociationsByUid, findVehicleModelById, findVehicleModelsInProject, findVehicleModelsInCompany,
    findAllVehicleModels, findVehicleModelByName, createVehicleModel, updateVehicleModel, findAllDriversLicensesInCompany,
    findDriverLicenses, findVehiclesCertInCompany, findAllVehiclesCert, findVehicleCertification, removeDriverLicenses,
    addDriverLicense, addVehicleCertification, updateVehicleCertification, removeVehicleModel, updateDriverLicVehCert,
    findAllDriversLicenses, findAllDriversLicensesInProject, findVehiclesCertInProject, findVehicleModelsCount,
} = require('./sqls');


class CertificationRepo {
    // CERTIFICATIONS
    static async findAllVehicleModels(company_uid, project_uid) {
        if (project_uid) {
            return db.queryAsync(findVehicleModelsInProject(), [project_uid]);
        } else if (company_uid && company_uid !== 'company_uid') {
            return db.queryAsync(findVehicleModelsInCompany(), [company_uid]);
        }
        return db.queryAsync(findAllVehicleModels());
    }
    static async findVehicleModelByName(name, project_uid) {
        return db.queryAsync(findVehicleModelByName(), [name, project_uid]).get(0);
    }
    static async findVehicleModelsCount(project_uid) {
        const result = await db.queryAsync(findVehicleModelsCount(), [project_uid]).get(0);
        return result && Number(result.totalCount);
    }
    static async findVehicleModelById(id, project_uid) {
        return db.queryAsync(findVehicleModelById(), [id, project_uid]).get(0);
    }
    static async createVehicleModel({ name, company_uid, project_uid, certification_required }) {
        const certified = certification_required ? 1 : 0;
        return db.queryAsync(createVehicleModel(), [name, company_uid, project_uid, certified]);
    }
    static async updateVehicleModel({ name, project_uid, id, certification_required }) {
        const certified = certification_required ? 1 : 0;
        return db.queryAsync(updateVehicleModel(), [name, certified, project_uid, id]);
    }
    static async deleteVehicleModel(id, project_uid) {
        return db.queryAsync(removeVehicleModel(), [id, project_uid]);
    }

    // DRIVER LICENSE
    static async findAllDriversLicenses({ company_uid, project_uid }) {
        if (project_uid) {
            return db.queryAsync(findAllDriversLicensesInProject(), [project_uid]);
        } else if (company_uid && company_uid !== 'company_uid') {
            return db.queryAsync(findAllDriversLicensesInCompany(), [company_uid]);
        }
        return db.queryAsync(findAllDriversLicenses());
    }
    static async findDriverLicenses(obj_uid) {
        return db.queryAsync(findDriverLicenses(), [obj_uid]);
    }
    static async addDriverLicenses({ obj_uid, company_uid, project_uid, cert }) {
        return db.queryAsync(addDriverLicense(), [obj_uid, company_uid, project_uid, cert]);
    }
    static async deleteDriverLicenses(obj_uid) {
        return db.queryAsync(removeDriverLicenses(), [obj_uid]);
    }

    // VEHICLE CERTIFICATION
    static async findAllVehCert({ company_uid, project_uid }) {
        if (project_uid) {
            return db.queryAsync(findVehiclesCertInProject(), [project_uid]);
        } else if (company_uid && company_uid !== 'company_uid') {
            return db.queryAsync(findVehiclesCertInCompany(), [company_uid]);
        }
        return db.queryAsync(findAllVehiclesCert());
    }
    static async findVehCert(obj_uid) {
        return db.queryAsync(findVehicleCertification(), [obj_uid]).get(0);
    }
    static async addVehicleCertification({ obj_uid, company_uid, project_uid, id }) {
        return db.queryAsync(addVehicleCertification(), [obj_uid, company_uid, project_uid, id]);
    }
    static async updateVehicleCertification({ id, obj_uid, project_uid }) {
        return db.queryAsync(updateVehicleCertification(), [id, obj_uid, project_uid]);
    }
    static async updateDriverLicVehicleCert({ id, project_uid }) {
        return db.queryAsync(updateDriverLicVehCert(), [id, project_uid, id, project_uid]);
    }
    static async deleteVehicleCertifications(uid) {
        return db.queryAsync(deleteVehiclesModelAssociationsByUid(), [uid]);
    }
}

module.exports = {
    CertificationRepo,
};
