function deleteVehiclesModelAssociationsByUid() {
    return 'delete from vehicles_model_associations where obj_uid = ?';
}

function findVehicleModelsInProject() {
    return 'SELECT model as name, id, certification_required FROM vehicle_models WHERE project_uid = ?';
}

function findVehicleModelsInCompany() {
    return 'SELECT model as name, id, certification_required FROM vehicle_models WHERE company_uid = ?';
}

function findAllVehicleModels() {
    return 'SELECT model as name, id, certification_required FROM vehicle_models';
}

function findVehicleModelByName() {
    return 'SELECT model as name, id, certification_required FROM vehicle_models WHERE model = ? AND project_uid = ?';
}

function findVehicleModelsCount() {
    return 'SELECT count(*) as totalCount FROM vehicle_models WHERE project_uid = ?';
}

function findVehicleModelById() {
    return 'SELECT model as name, id, certification_required FROM vehicle_models WHERE id = ? AND project_uid = ?';
}

function createVehicleModel() {
    return 'INSERT INTO vehicle_models SET model = ?, company_uid = ?, project_uid = ?, certification_required = ?';
}

function updateVehicleModel() {
    return 'UPDATE vehicle_models SET model = ?, certification_required = ? WHERE project_uid = ? AND id = ?';
}

function findAllDriversLicensesInProject() {
    return `
    SELECT ds.obj_uid, CONCAT_WS(',',GROUP_CONCAT(DISTINCT vm.model ORDER BY vm.id SEPARATOR  ',' )) as licenses,
           CONCAT_WS(',', GROUP_CONCAT( DISTINCT vm.id ORDER BY vm.id SEPARATOR  ',')) as ids,
           CONCAT_WS(',', GROUP_CONCAT( vm.certification_required ORDER BY vm.id SEPARATOR  ',')) as certs
    FROM driver_certifications ds
             JOIN vehicle_models vm ON (vm.company_uid = ds.company_uid) AND (vm.id = ds.id ) AND (vm.project_uid = ds.project_uid)
    WHERE ds.project_uid =  ?
    GROUP BY ds.obj_uid;
`;
}

function findAllDriversLicensesInCompany() {
    return `
    SELECT ds.obj_uid, CONCAT_WS(',',GROUP_CONCAT(DISTINCT vm.model ORDER BY vm.id SEPARATOR  ',' )) as licenses,
           CONCAT_WS(',', GROUP_CONCAT( DISTINCT vm.id ORDER BY vm.id SEPARATOR  ',')) as ids,
           CONCAT_WS(',', GROUP_CONCAT( vm.certification_required ORDER BY vm.id SEPARATOR  ',')) as certs
    FROM driver_certifications ds
             JOIN vehicle_models vm ON (vm.company_uid = ds.company_uid) AND (vm.id = ds.id ) AND (vm.project_uid = ds.project_uid)
    WHERE ds.company_uid =  ?
    GROUP BY ds.obj_uid;
`;
}

function findAllDriversLicenses() {
    return `
    SELECT ds.obj_uid, CONCAT_WS(',',GROUP_CONCAT(DISTINCT vm.model ORDER BY vm.id SEPARATOR  ',' )) as licenses,
           CONCAT_WS(',', GROUP_CONCAT( DISTINCT vm.id ORDER BY vm.id SEPARATOR  ',')) as ids,
           CONCAT_WS(',', GROUP_CONCAT( vm.certification_required ORDER BY vm.id SEPARATOR  ',')) as certs
    FROM driver_certifications ds
             JOIN vehicle_models vm ON (vm.company_uid = ds.company_uid) AND (vm.id = ds.id ) AND (vm.project_uid = ds.project_uid)
    GROUP BY ds.obj_uid;
`;
}

function findDriverLicenses() {
    return `
    SELECT ds.obj_uid, CONCAT_WS(',',GROUP_CONCAT(DISTINCT vm.model ORDER BY vm.id SEPARATOR  ',' )) as licenses,
           CONCAT_WS(',', GROUP_CONCAT( DISTINCT vm.id ORDER BY vm.id SEPARATOR  ',')) as ids,
           CONCAT_WS(',', GROUP_CONCAT( vm.certification_required ORDER BY vm.id SEPARATOR  ',')) as certs
    FROM driver_certifications ds
             JOIN vehicle_models vm ON (vm.company_uid = ds.company_uid) AND (vm.id = ds.id) AND (vm.project_uid = ds.project_uid)
    WHERE ds.obj_uid = ?
    GROUP BY ds.obj_uid;
`;
}

function findVehiclesCertInProject() {
    return `
    SELECT ds.obj_uid, vm.model as name, vm.id, vm.certification_required
    FROM vehicles_model_associations ds
             JOIN vehicle_models vm ON vm.id = ds.id AND vm.company_uid = ds.company_uid AND vm.project_uid = ds.project_uid
    WHERE ds.project_uid = ?;
`;
}

function findVehiclesCertInCompany() {
    return `
    SELECT ds.obj_uid, vm.model as name, vm.id, vm.certification_required
    FROM vehicles_model_associations ds
             JOIN vehicle_models vm ON vm.id = ds.id AND vm.company_uid = ds.company_uid AND vm.project_uid = ds.project_uid
    WHERE ds.company_uid = ?;
`;
}
function findAllVehiclesCert() {
    return `
    SELECT ds.obj_uid, vm.model as name, vm.id, vm.certification_required
    FROM vehicles_model_associations ds
             JOIN vehicle_models vm ON vm.id = ds.id AND vm.company_uid = ds.company_uid AND vm.project_uid = ds.project_uid;
`;
}

function findVehicleCertification() {
    return `
    SELECT vma.obj_uid, vm.model as name, vma.id, vm.certification_required
    FROM vehicles_model_associations vma
             LEFT JOIN vehicle_models vm ON vm.id = vma.id AND vm.company_uid = vma.company_uid AND vm.project_uid = vma.project_uid
    WHERE vma.obj_uid = ?;
`;
}

function removeDriverLicenses() {
    return 'DELETE FROM driver_certifications WHERE obj_uid = ?';
}

function addDriverLicense() {
    return `
    INSERT INTO driver_certifications  
    SET obj_uid = ?,
        company_uid = ?,
        project_uid = ?,
        id = ?;
    `;
}

function addVehicleCertification() {
    return `
    INSERT  INTO   vehicles_model_associations
    SET obj_uid = ?,
        company_uid = ?,
        project_uid = ?,
        id = ?;
`;
}

function updateVehicleCertification() {
    return `
    update vehicles_model_associations
    SET id = ?
    WHERE obj_uid = ?
    AND project_uid = ?;
`;
}

function removeVehicleModel() {
    return `
    DELETE FROM vehicle_models
    WHERE id = ?
    AND project_uid = ?
`;
}

function updateDriverLicVehCert() {
    return `
    DELETE FROM driver_certifications
    WHERE id = ?
    AND project_uid = ?;
    DELETE FROM vehicles_model_associations
    WHERE id = ?
    AND project_uid = ?;
`;
}

module.exports = {
    deleteVehiclesModelAssociationsByUid,
    findVehicleModelsCount,
    findVehicleModelsInProject,
    findVehicleModelsInCompany,
    findAllVehicleModels,
    findVehicleModelByName,
    createVehicleModel,
    updateVehicleModel,
    findAllDriversLicensesInCompany,
    findAllDriversLicenses,
    findDriverLicenses,
    findVehiclesCertInCompany,
    findAllVehiclesCert,
    findVehicleCertification,
    removeDriverLicenses,
    addDriverLicense,
    addVehicleCertification,
    updateVehicleCertification,
    removeVehicleModel,
    updateDriverLicVehCert,
    findVehicleModelById,
    findAllDriversLicensesInProject,
    findVehiclesCertInProject,
};
